# Copyright (c) 2008-2009 Michael Howitz
# See also LICENSE.txt
# $Id: install.py 913 2009-01-02 12:47:38Z mac $
"""Initial generation."""


def evolve(context):
    # nothing to install initially
    pass
