# -*- coding: latin-1 -*-
# Copyright (c) 2008-2009 Michael Howitz
# See also LICENSE.txt
# $Id: i18n.py 913 2009-01-02 12:47:38Z mac $

"""I18n message factory for icemac.addressbook. """

import zope.i18nmessageid

MessageFactory = zope.i18nmessageid.MessageFactory('icemac.addressbook')
